@@ -5,7 +5,7 @@
 modname = "cubicweb_oauth2"
 distname = "cubicweb-oauth2"
 
-numversion = (0, 2, 0)
+numversion = (0, 3, 2)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -15,7 +15,7 @@ description = "Oauth2/OpenID authentication for cubicweb"
 web = "http://www.cubicweb.org/project/%s" % distname
 
 __depends__ = {
-    "cubicweb[pyramid]": ">= 3.28.2",
+    "cubicweb": ">= 3.32.1",
     "authlib": None,
     "requests": None,
 }
